@@ -2,7 +2,7 @@ from pathlib import Path
 import shutil
 from subprocess import call
 
-from django.core.management.base import BaseCommand
+from base.management import BaseCommand
 from django.core.management import call_command
 from django.conf import settings
 
@@ -33,7 +33,7 @@ class Command(BaseCommand):
         conf_file = p / 'babel.config.js'
 
         if not conf_file.exists():
-            print(f'Creating "babel.config.js" at {p}.')
+            self.stdout.write(f'Creating "babel.config.js" at {p}.')
             conf_file.write_text(BABEL_CONF)
 
         command_array = [
