@@ -1,6 +1,6 @@
 import shutil
 from subprocess import call
-from django.core.management.base import BaseCommand
+from base.management import BaseCommand
 from django.conf import settings
 
 
@@ -8,11 +8,12 @@ class Command(BaseCommand):
     help = 'Check Python files for PEP8 compliance'
 
     def handle(self, *args, **options):
+        self.stdout.write("Linting Python code...")
         shutil.os.chdir(settings.PROJECT_PATH)
         return_value = call([
             "flake8",
             "--exclude",
-            "node_modules/*,*/migrations/*,venv/*,configuration.py",
+            "node_modules/*,*/migrations/*,venv/*,.direnv/*,configuration.py",
             "./"
         ])
         if return_value > 0:
