@@ -1,6 +1,6 @@
 import os
 
-from django.core.management.base import BaseCommand
+from base.management import BaseCommand
 from django.core.management.utils import get_random_secret_key
 from django.conf import settings
 
