@@ -27,7 +27,7 @@ def update_node(node):
             if not "attrs" in node:
                 node["attrs"] = {}
             ID_COUNTER += 1
-            node["attrs"]["id"] = "{}{:0>8d}".format("L", ID_COUNTER)
+            node["attrs"]["id"] = "{}{:0>8d}".format("T", ID_COUNTER)
             node["attrs"]["caption"] = False
             if "content" in node:
                 node["content"] = [
@@ -135,8 +135,6 @@ def update_revision_zip(file_field, file_name):
                     zout.writestr(item, str(FW_DOCUMENT_VERSION))
                 elif item.filename == 'document.json':
                     doc_string = zin.read(item.filename)
-                    #print(doc_string)
-                    #print(update_document_string(doc_string))
                     zout.writestr(
                         item,
                         update_document_string(doc_string)
@@ -150,11 +148,14 @@ def update_revision_zip(file_field, file_name):
 
 def update_documents(apps, schema_editor):
     Document = apps.get_model('document', 'Document')
-    documents = Document.objects.all()
+    documents = Document.objects.all().iterator()
     for document in documents:
         if document.doc_version == Decimal(str(OLD_FW_DOCUMENT_VERSION)):
             document.contents = update_document_string(document.contents)
             document.doc_version = FW_DOCUMENT_VERSION
+            for field in document._meta.local_fields:
+                if field.name == "updated":
+                    field.auto_now = False
             document.save()
 
     DocumentTemplate = apps.get_model('document', 'DocumentTemplate')
