@@ -93,6 +93,7 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         ).send_keys(
             "An abstract title"
         ).perform()
+        time.sleep(1)
         self.driver.find_element(
             By.CSS_SELECTOR,
             "#toolbar > div > div > div:nth-child(3) > div"
@@ -104,7 +105,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
                 "ul > li:nth-child(4) > span > label"
             )
         ).click()
-        # We type in th body
+        # We type in the body
+        self.driver.find_element(By.CSS_SELECTOR, ".article-body").click()
         self.driver.find_element(By.CSS_SELECTOR, ".article-body").send_keys(
             "Body"
         )
@@ -113,10 +115,16 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         button.click()
 
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.presence_of_element_located((By.CLASS_NAME, "caption"))
-        ).send_keys('Caption')
-        self.driver.find_element_by_id("figure-category-btn").click()
-        self.driver.find_element_by_id("figure-category-photo").click()
+            EC.presence_of_element_located(
+                (By.CSS_SELECTOR, "span.math-field")
+            )
+        )
+        self.driver.find_element_by_css_selector(
+            "div.figure-category"
+        ).click()
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Photo"]'
+        ).click()
 
         # click on 'Insert image' button
         self.driver.find_element_by_id('insert-figure-image').click()
@@ -163,6 +171,17 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             '//*[normalize-space()="Use image"]'
         ).click()
         self.driver.find_element_by_css_selector("button.fw-dark").click()
+
+        caption = WebDriverWait(self.driver, self.wait_time).until(
+            EC.presence_of_element_located(
+                (By.CSS_SELECTOR, "div.article-body figure figcaption")
+            )
+        )
+
+        caption.click()
+
+        caption.send_keys("Caption")
+
         ActionChains(self.driver).send_keys(
             Keys.RIGHT
         ).perform()
@@ -289,12 +308,17 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         ).perform()
         button = self.driver.find_element_by_xpath('//*[@title="Figure"]')
         button.click()
-
         WebDriverWait(self.driver, self.wait_time).until(
-            EC.presence_of_element_located((By.CLASS_NAME, "caption"))
-        ).send_keys('Caption 2')
-        self.driver.find_element_by_id("figure-category-btn").click()
-        self.driver.find_element_by_id("figure-category-photo").click()
+            EC.presence_of_element_located(
+                (By.CSS_SELECTOR, "span.math-field")
+            )
+        )
+        self.driver.find_element_by_css_selector(
+            "div.figure-category"
+        ).click()
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Photo"]'
+        ).click()
 
         # click on 'Insert image' button
         self.driver.find_element_by_id('insert-figure-image').click()
@@ -623,9 +647,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
                 (By.CSS_SELECTOR, ".collaborator-tr .fa-caret-down")
             )
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-pulldown-item[data-rights=write]"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Write"]'
         ).click()
         self.driver.find_element(
             By.CSS_SELECTOR,
@@ -635,9 +658,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             By.CSS_SELECTOR,
             "tr:nth-child(3) .fa-caret-down"
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            "tr:nth-child(3) .fw-pulldown-item[data-rights=write]"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Write"]'
         ).click()
         self.driver.find_element(
             By.CSS_SELECTOR,
@@ -680,9 +702,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             By.CSS_SELECTOR,
             "tr:nth-child(3) .fa-caret-down.edit-right"
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            "tr:nth-child(3) .fw-pulldown-item[data-rights=read]"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Read"]'
         ).click()
         self.driver.find_element(
             By.CSS_SELECTOR,
@@ -703,9 +724,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable((By.ID, 'preferences-btn'))
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         # Second user logs in, verifies that he has access
         self.driver.find_element(By.ID, "id_login").send_keys("Yeti2")
@@ -745,6 +765,7 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         ).send_keys(
             Keys.ENTER
         ).perform()
+        time.sleep(1)
         assert self.driver.find_element(
             By.CSS_SELECTOR,
             ".article-title"
@@ -757,9 +778,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable((By.ID, 'preferences-btn'))
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         # First user logs in again, removes access rights of second user
         self.driver.find_element(By.ID, "id_login").send_keys("Yeti")
@@ -809,9 +829,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable((By.ID, 'preferences-btn'))
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         # Second user logs in again to verify that access rights are gone
         self.driver.find_element(By.ID, "id_login").send_keys("Yeti2")
@@ -835,9 +854,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable((By.ID, 'preferences-btn'))
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         # Third user signs up
         self.driver.find_element(
@@ -860,6 +878,10 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             By.ID,
             'id_email'
         ).send_keys('yeti3@snowman.com')
+        # Scroll all the way down in case we are on a small screen
+        self.driver.execute_script(
+            "window.scrollTo(0, document.body.scrollHeight);"
+        )
         self.driver.find_element(
             By.ID,
             'signup-submit'
@@ -990,9 +1012,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
                 (By.CSS_SELECTOR, ".collaborator-tr .fa-caret-down")
             )
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-pulldown-item[data-rights=write]"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Write"]'
         ).click()
         self.driver.find_element(
             By.CSS_SELECTOR,
@@ -1041,9 +1062,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable((By.ID, 'preferences-btn'))
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         WebDriverWait(self.driver, self.wait_time).until(
             EC.element_to_be_clickable(
@@ -1137,9 +1157,8 @@ class EditorTest(LiveTornadoTestCase, SeleniumHelper):
             By.CSS_SELECTOR,
             "#preferences-btn"
         ).click()
-        self.driver.find_element(
-            By.CSS_SELECTOR,
-            ".fw-logout-button"
+        self.driver.find_element_by_xpath(
+            '//*[normalize-space()="Log out"]'
         ).click()
         # User 5 signs up with a different email first and then clicks the
         # invitation link. This should land user 5 directly in the editor.
