@@ -6,6 +6,7 @@ from django.http import JsonResponse
 from django.core.serializers.python import Serializer
 from django.utils.translation import ugettext as _
 from django.views.decorators.http import require_POST
+from django.conf import settings
 
 from base.decorators import ajax_required
 from usermedia.models import Image, ImageCategory, UserImage
@@ -33,6 +34,10 @@ def save(request):
             request.FILES['image'].content_type not in ALLOWED_FILETYPES:
         status = 200  # Not implemented
         response['errormsg']['error'] = _('Filetype not supported')
+    elif settings.MEDIA_MAX_SIZE and 'image' in request.FILES and \
+            request.FILES['image'].size > settings.MEDIA_MAX_SIZE:
+        status = 413
+        response['errormsg']['error'] = _('Image too large')
     else:
         image = False
         if 'id' in request.POST and 'image' not in request.FILES:
@@ -53,9 +58,9 @@ def save(request):
                 image.checksum = request.POST['checksum']
         user_image.title = request.POST['title']
         if 'copyright' in request.POST:
-            user_image.copyright = request.POST['copyright']
+            user_image.copyright = json.loads(request.POST['copyright'])
         if 'cats' in request.POST:
-            user_image.image_cat = request.POST['cats']
+            user_image.cats = json.loads(request.POST['cats'])
         if 'image' in request.FILES:
             image.image = request.FILES['image']
         if status == 201 and 'image' not in request.FILES:
@@ -68,12 +73,12 @@ def save(request):
             response['values'] = {
                 'id': image.id,
                 'title': user_image.title,
-                'copyright': json.loads(user_image.copyright),
+                'copyright': user_image.copyright,
                 'image': image.image.url,
                 'file_type': image.file_type,
                 'added': mktime(image.added.timetuple()) * 1000,
                 'checksum': image.checksum,
-                'cats': json.loads(user_image.image_cat)
+                'cats': user_image.cats
             }
             if image.thumbnail:
                 response['values']['thumbnail'] = image.thumbnail.url
@@ -123,12 +128,12 @@ def images(request):
             field_obj = {
                 'id': image.id,
                 'title': user_image.title,
-                'copyright': json.loads(user_image.copyright),
+                'copyright': user_image.copyright,
                 'image': image.image.url,
                 'file_type': image.file_type,
                 'added': mktime(image.added.timetuple()) * 1000,
                 'checksum': image.checksum,
-                'cats': json.loads(user_image.image_cat)
+                'cats': user_image.cats
             }
             if image.thumbnail:
                 field_obj['thumbnail'] = image.thumbnail.url
